@@ -22,13 +22,10 @@
 #include <ctype.h>
 #include <string.h>
 #include <stdlib.h>
-
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <glib/gi18n.h>
 
-#include <loudmouth/loudmouth.h>
-
 #include <libgossip/gossip-account.h>
 #include <libgossip/gossip-protocol.h>
 #include <libgossip/gossip-utils.h>
@@ -228,6 +225,7 @@ accounts_dialog_setup (GossipAccountsDialog *dialog)
 				  G_CALLBACK (accounts_dialog_account_name_changed_cb), dialog);
 	}
 
+	g_list_foreach (accounts, (GFunc) g_object_unref, NULL);
 	g_list_free (accounts);
 }
 
@@ -1515,7 +1513,7 @@ gossip_accounts_dialog_show (GossipAccount *account)
 	
 	dialog = g_new0 (GossipAccountsDialog, 1);
 
-	glade = gossip_glade_get_file (GLADEDIR "/main.glade",
+	glade = gossip_glade_get_file ("main.glade",
 				       "accounts_dialog",
 				       NULL,
 				       "accounts_dialog", &dialog->window,
