@@ -48,6 +48,51 @@
 
 #define DEBUG_DOMAIN "ChatWindow"
 
+#define URGENCY_TIMEOUT 60*1000
+
+struct _GossipChatWindowPriv {
+	GList       *chats;
+	GList       *chats_new_msg;
+	GList       *chats_composing;
+
+	GossipChat  *current_chat;
+
+	gboolean     new_msg;
+
+	guint        urgency_timeout_id;
+	
+	GtkWidget   *dialog;
+	GtkWidget   *notebook;
+
+	GtkTooltips *tooltips;
+
+	/* Menu items. */
+	GtkWidget   *menu_conv_clear;
+	GtkWidget   *menu_conv_log;
+	GtkWidget   *menu_conv_separator;
+	GtkWidget   *menu_conv_add_contact;
+	GtkWidget   *menu_conv_info;
+	GtkWidget   *menu_conv_close;
+
+	GtkWidget   *menu_room;
+	GtkWidget   *menu_room_invite;
+	GtkWidget   *menu_room_add;
+	GtkWidget   *menu_room_show_contacts;
+
+	GtkWidget   *menu_edit_insert_smiley;
+	GtkWidget   *menu_edit_cut;
+	GtkWidget   *menu_edit_copy;
+	GtkWidget   *menu_edit_paste;
+
+	GtkWidget   *menu_tabs_next;
+	GtkWidget   *menu_tabs_prev;
+	GtkWidget   *menu_tabs_left;
+	GtkWidget   *menu_tabs_right;
+	GtkWidget   *menu_tabs_detach;
+
+	guint        save_geometry_id;
+};
+
 static void       gossip_chat_window_class_init         (GossipChatWindowClass *klass);
 static void       gossip_chat_window_init               (GossipChatWindow      *window);
 static void       gossip_chat_window_finalize           (GObject               *object);
@@ -95,7 +140,9 @@ static void       chat_window_insert_smiley_activate_cb (GtkWidget             *
 							 GossipChatWindow      *window);
 static void       chat_window_close_activate_cb         (GtkWidget             *menuitem,
 							 GossipChatWindow      *window);
-static void       chat_window_add_room_activate_cb      (GtkWidget             *menuitem,
+static void       chat_window_room_invite_activate_cb   (GtkWidget             *menuitem,
+							 GossipChatWindow      *window);
+static void       chat_window_room_add_activate_cb      (GtkWidget             *menuitem,
 							 GossipChatWindow      *window);
 static void       chat_window_cut_activate_cb           (GtkWidget             *menuitem,
 							 GossipChatWindow      *window);
@@ -153,54 +200,9 @@ static void       chat_window_drag_data_received        (GtkWidget             *
 							 guint                  info,
 							 guint                  time,
 							 GossipChatWindow      *window);
-static void       chat_window_set_urgency_hint           (GossipChatWindow     *window,
-							  gboolean              urgent);
+static void       chat_window_set_urgency_hint          (GossipChatWindow      *window,
+							 gboolean               urgent);
 
-/* Called from Glade, so it shouldn't be static. */
-GtkWidget * chat_window_create_notebook (gpointer data);
-
-struct _GossipChatWindowPriv {
-	GList       *chats;
-	GList       *chats_new_msg;
-	GList       *chats_composing;
-
-	GossipChat  *current_chat;
-
-	gboolean     new_msg;
-
-	guint        urgency_timeout_id;
-	
-	GtkWidget   *dialog;
-	GtkWidget   *notebook;
-
-	GtkTooltips *tooltips;
-
-	/* Menu items. */
-	GtkWidget   *menu_conv_clear;
-	GtkWidget   *menu_conv_log;
-	GtkWidget   *menu_conv_separator;
-	GtkWidget   *menu_conv_add_contact;
-	GtkWidget   *menu_conv_info;
-	GtkWidget   *menu_conv_close;
-
-	GtkWidget   *menu_room;
-	GtkWidget   *menu_room_invite;
-	GtkWidget   *menu_room_add;
-	GtkWidget   *menu_room_show_contacts;
-
-	GtkWidget   *menu_edit_insert_smiley;
-	GtkWidget   *menu_edit_cut;
-	GtkWidget   *menu_edit_copy;
-	GtkWidget   *menu_edit_paste;
-
-	GtkWidget   *menu_tabs_next;
-	GtkWidget   *menu_tabs_prev;
-	GtkWidget   *menu_tabs_left;
-	GtkWidget   *menu_tabs_right;
-	GtkWidget   *menu_tabs_detach;
-
-	guint        save_geometry_id;
-};
 
 static GList *chat_windows = NULL;
 
@@ -209,9 +211,9 @@ static const guint tab_accel_keys[] = {
 	GDK_6, GDK_7, GDK_8, GDK_9, GDK_0
 };
 
-enum DndDropType {
+typedef enum {
 	DND_DROP_TYPE_CONTACT_ID,
-};
+} DndDropType;
 
 static const GtkTargetEntry drop_types[] = {
 	{ "text/contact-id", 0, DND_DROP_TYPE_CONTACT_ID },
@@ -219,8 +221,6 @@ static const GtkTargetEntry drop_types[] = {
 
 G_DEFINE_TYPE (GossipChatWindow, gossip_chat_window, G_TYPE_OBJECT);
 
-#define URGENCY_TIMEOUT 60*1000
-
 static void
 gossip_chat_window_class_init (GossipChatWindowClass *klass)
 {
@@ -232,12 +232,12 @@ gossip_chat_window_class_init (GossipChatWindowClass *klass)
 
 	/* Set up a style for the close button with no focus padding. */ 	 
 	gtk_rc_parse_string ( 	 
-		"style \"gossip-close-button-style\"\n" 	 
-		"{\n" 	 
-		"  GtkWidget::focus-padding = 0\n" 	 
-		"  xthickness = 0\n" 	 
-		"  ythickness = 0\n" 	 
-		"}\n" 	 
+		"style \"gossip-close-button-style\"\n"
+		"{\n"
+		"  GtkWidget::focus-padding = 0\n"
+		"  xthickness = 0\n"
+		"  ythickness = 0\n"
+		"}\n"
 		"widget \"*.gossip-close-button\" style \"gossip-close-button-style\"");
 }
 
@@ -252,6 +252,7 @@ gossip_chat_window_init (GossipChatWindow *window)
 	GtkWidget            *menu_conv;
 	GtkWidget            *menu;
 	gint                  i;
+	GtkWidget            *chat_vbox;
 
 	priv = GET_PRIV (window);
 
@@ -262,7 +263,7 @@ gossip_chat_window_init (GossipChatWindow *window)
 				       "chat_window",
 				       NULL,
 				       "chat_window", &priv->dialog,
-				       "chats_notebook", &priv->notebook,
+				       "chat_vbox", &chat_vbox,
 				       "menu_conv", &menu_conv,
 				       "menu_conv_clear", &priv->menu_conv_clear,
 				       "menu_conv_log", &priv->menu_conv_log,
@@ -294,7 +295,8 @@ gossip_chat_window_init (GossipChatWindow *window)
 			      "menu_conv_add_contact", "activate", chat_window_add_contact_activate_cb,
 			      "menu_conv_info", "activate", chat_window_info_activate_cb,
 			      "menu_conv_close", "activate", chat_window_close_activate_cb,
-			      "menu_room_add", "activate", chat_window_add_room_activate_cb,
+			      "menu_room_invite", "activate", chat_window_room_invite_activate_cb,
+			      "menu_room_add", "activate", chat_window_room_add_activate_cb,
 			      "menu_edit", "activate", chat_window_edit_activate_cb,
 			      "menu_edit_cut", "activate", chat_window_cut_activate_cb,
 			      "menu_edit_copy", "activate", chat_window_copy_activate_cb,
@@ -306,6 +308,10 @@ gossip_chat_window_init (GossipChatWindow *window)
 
 	g_object_unref (glade);
 
+	priv->notebook = gossip_notebook_new ();
+	gtk_widget_show (priv->notebook);
+	gtk_box_pack_start (GTK_BOX (chat_vbox), priv->notebook, TRUE, TRUE, 0);
+	
 	/* Set up accels */
 	accel_group = gtk_accel_group_new ();
 	gtk_window_add_accel_group (GTK_WINDOW (priv->dialog), accel_group);
@@ -594,8 +600,9 @@ chat_window_create_label (GossipChatWindow *window,
 	GtkRequisition        size;
 
 	priv = GET_PRIV (window);
-	
-	hbox = gtk_hbox_new (FALSE, 2);
+
+	/* The spacing between the button and the label. */
+	hbox = gtk_hbox_new (FALSE, 0);
 
  	event_box = gtk_event_box_new (); 
  	gtk_event_box_set_visible_window (GTK_EVENT_BOX (event_box), FALSE); 
@@ -618,6 +625,7 @@ chat_window_create_label (GossipChatWindow *window,
 
 	status_image = gtk_image_new ();
 
+	/* Spacing between the icon and label. */
 	event_box_hbox = gtk_hbox_new (FALSE, 2);
 
 	gtk_box_pack_start (GTK_BOX (event_box_hbox), status_image, FALSE, FALSE, 0);
@@ -667,81 +675,6 @@ chat_window_create_label (GossipChatWindow *window,
 	gtk_widget_hide (close_button);
 
 	return hbox;
-
-#if 0
-	GossipChatWindowPriv *priv;
-	GtkWidget            *hbox;
-	GtkWidget            *label;
-	GtkWidget            *image;
-	const gchar          *name;
-	GtkWidget            *event_box_tab; 
-	GtkWidget            *event_box_image;
-	PangoAttrList        *attr_list;
-	PangoAttribute       *attr;
-
-	priv = GET_PRIV (window);
-
-	/* Set up event box for tooltip */
- 	event_box_tab = gtk_event_box_new (); 
- 	gtk_event_box_set_visible_window (GTK_EVENT_BOX (event_box_tab), FALSE); 
-  	g_object_set_data (G_OBJECT (chat), "chat-window-tab-tooltip-widget", event_box_tab);
-
-	/* Set up label */
-	name = gossip_chat_get_name (chat);
-	label = gtk_label_new (name);
-
-	gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
-	
-	attr_list = pango_attr_list_new ();
-	attr = pango_attr_scale_new (1/1.2);
-	attr->start_index = 0;
-	attr->end_index = -1;
-	pango_attr_list_insert (attr_list, attr);
-	gtk_label_set_attributes (GTK_LABEL (label), attr_list);
-	pango_attr_list_unref (attr_list);
-
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	g_object_set_data (G_OBJECT (chat), "chat-window-tab-label", label); 
-
-	/* Set up event box for label */
- 	event_box_image = gtk_event_box_new ();
- 	gtk_event_box_set_visible_window (GTK_EVENT_BOX (event_box_image), FALSE);
-
-	/* Set up image */
-	image = gtk_image_new ();
-	g_object_set_data (G_OBJECT (chat), "chat-window-tab-image", image);
-
- 	gtk_container_add (GTK_CONTAINER (event_box_image), image); 
-
-	/* Add to the hbox */
-	hbox = gtk_hbox_new (FALSE, 2);
-  	gtk_box_pack_start (GTK_BOX (hbox), event_box_image, FALSE, FALSE, 0);  
-	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
-
-	/* Add the hbox to the tooltip event box, this way both the
-	 * image and the label get the tooltip text.
-	 */
-	gtk_container_add (GTK_CONTAINER (event_box_tab), hbox);
-
-	/* Set up motion events for both event boxes */
-	gtk_widget_add_events (event_box_image, 
-			       GDK_ENTER_NOTIFY_MASK |
-			       GDK_LEAVE_NOTIFY_MASK);
-	g_signal_connect (event_box_image, "enter-notify-event",
-			  G_CALLBACK (chat_window_status_enter_notify_cb),
-			  chat);
-	g_signal_connect (event_box_image, "leave-notify-event",
-			  G_CALLBACK (chat_window_tab_leave_notify_cb),
-			  chat);
-
-	/* Set up tooltip */
-	chat_window_update_tooltip (window, chat);
-
-	/* Make everything visible */
-	gtk_widget_show_all (event_box_tab);
-
-	return event_box_tab;
-#endif
 }
 
 static void
@@ -799,7 +732,6 @@ chat_window_update_menu (GossipChatWindow *window)
 	GossipChatWindowPriv *priv;
 	GossipContact        *contact;
 	GossipContact        *own_contact;
-	GtkWidget            *invite_menu = NULL;
 	gboolean              show_contacts;
 	gboolean              first_page;
 	gboolean              last_page;
@@ -842,9 +774,6 @@ chat_window_update_menu (GossipChatWindow *window)
 		gtk_widget_hide (priv->menu_conv_add_contact);
 		gtk_widget_hide (priv->menu_conv_info);
 
-		/* Set up invite menu */
-		invite_menu = gossip_chat_invite_groupchat_menu (own_contact, id);
-
 		/* Can we add this room to our favourites? */
 		manager = gossip_app_get_chatroom_manager ();
 		if (gossip_chatroom_manager_find (manager, id)) {
@@ -888,20 +817,6 @@ chat_window_update_menu (GossipChatWindow *window)
 
 		gtk_widget_show (priv->menu_conv_separator);
 		gtk_widget_show (priv->menu_conv_info);
-
-		/* Set up invite menu */
- 		invite_menu = gossip_chat_invite_contact_menu (own_contact); 	
-	}
-
-	if (invite_menu) {
-		gtk_widget_set_sensitive (priv->menu_room_invite, TRUE);
-
-		gtk_widget_show_all (invite_menu);
-		gtk_menu_item_set_submenu (GTK_MENU_ITEM (priv->menu_room_invite), invite_menu);
-	} else {
-		gtk_menu_item_remove_submenu (GTK_MENU_ITEM (priv->menu_room_invite));
-
-		gtk_widget_set_sensitive (priv->menu_room_invite, FALSE);
 	}
 }
 
@@ -987,12 +902,13 @@ chat_window_info_activate_cb (GtkWidget        *menuitem,
 {
 	GossipChatWindowPriv *priv;
 	GossipContact        *contact;
-	
+
 	priv = GET_PRIV (window);
 
 	contact = gossip_chat_get_contact (priv->current_chat);
 
-	gossip_contact_info_dialog_show (contact);
+	gossip_contact_info_dialog_show (contact, 
+					 GTK_WINDOW (priv->dialog));
 }
 
 static gboolean
@@ -1102,9 +1018,31 @@ chat_window_close_activate_cb (GtkWidget        *menuitem,
 
 	gossip_chat_window_remove_chat (window, priv->current_chat);
 }
+
+static void
+chat_window_room_invite_activate_cb (GtkWidget        *menuitem,
+				     GossipChatWindow *window)
+{
+	GossipChatWindowPriv *priv;
+	GossipContact        *own_contact;
+	GossipChatroomId      id = 0;
+
+	priv = GET_PRIV (window);
+
+	own_contact = gossip_chat_get_own_contact (priv->current_chat);
+
+	if (gossip_chat_is_group_chat (priv->current_chat)) {
+		GossipGroupChat *group_chat;
+
+		group_chat = GOSSIP_GROUP_CHAT (priv->current_chat);
+		id = gossip_group_chat_get_chatroom_id (group_chat);
+	}
+
+	gossip_chat_invite_dialog_show (own_contact, id);
+}
  
 static void
-chat_window_add_room_activate_cb (GtkWidget        *menuitem,
+chat_window_room_add_activate_cb (GtkWidget        *menuitem,
 				  GossipChatWindow *window)
 {
 	GossipChatWindowPriv   *priv;
@@ -1723,18 +1661,6 @@ chat_window_set_urgency_hint (GossipChatWindow *window,
 		window);
 }
 
-GtkWidget *
-chat_window_create_notebook (gpointer data)
-{
-	GtkWidget *notebook;
-
-	notebook = gossip_notebook_new ();
-
-	gtk_widget_show (notebook);
-
-	return notebook;
-}
-
 GossipChatWindow *
 gossip_chat_window_new (void)
 {
