@@ -23,7 +23,6 @@
 #include <stdio.h>
 #include <gtk/gtk.h>
 #include <glade/glade.h>
-#include <libgnome/gnome-config.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 
@@ -146,6 +145,8 @@ new_chatroom_dialog_update_join_button (GossipNewChatroomDialog *dialog)
 	GtkButton             *button;
 	GtkWidget             *image;
 
+	g_print ("update join, dialog: %p\n", dialog);
+	
 	/* First get button and icon */
 	button = GTK_BUTTON (dialog->button_join);
 
@@ -472,6 +473,8 @@ new_chatroom_dialog_response_cb (GtkWidget               *widget,
 		}
 
 		return;
+	} else {
+		new_chatroom_dialog_join_cancel (dialog);
 	}
 
 	gtk_widget_destroy (widget);
@@ -518,7 +521,7 @@ gossip_new_chatroom_dialog_show (GtkWindow *parent)
 	
         dialog = g_new0 (GossipNewChatroomDialog, 1);
 
-	glade = gossip_glade_get_file (GLADEDIR "/group-chat.glade",
+	glade = gossip_glade_get_file ("group-chat.glade",
 				       "new_chatroom_dialog",
 				       NULL,
 				       "new_chatroom_dialog", &dialog->window,
